@@ -1,4 +1,5 @@
 #include "CaenN6725.hh"
+#include "trapezoidal_shaper.h" 
 
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
@@ -648,4 +649,26 @@ PYBIND11_MODULE(_pyCaenN6725, m) {
         .def("readout_and_return",            &CaenN6725WF::readout_and_return)
         .def("set_input_dynamic_range",       &CaenN6725WF::set_input_dynamic_range)
         .def("get_input_dynamic_range",       &CaenN6725WF::get_input_dynamic_range);
+
+    // the trapezoidal filter
+    py::class_<TrapezoidalFilter>(m, "TrapezoidalFilter")
+        .def(py::init<int, int, int>())//,
+            // FIXME: the proper constructor with keyword support 
+            // py::arg("ptime"), py::kwarg("flat")=1000., py::kwarg("recordlength")=50000
+            //)
+        .def("shape_it", &TrapezoidalFilter::shape_it)
+        // we need __getstate__ and __setstate__ so that we are capable of pickling our class
+        // - this is important for the use with python multiprocessing module, 
+        // since this requires pickleable objects.
+        .def("__getstate__", [](const TrapezoidalFilter &t) {
+            return py::make_tuple(t.ptime, t.flat, t.recordlength);
+        })
+        .def("__setstate__", [](TrapezoidalFilter &trap, py::tuple t) {
+            if (t.size() != 3)
+                throw std::runtime_error("Invalid state!");
+            new (&trap) TrapezoidalFilter(t[0].cast<int>(),t[1].cast<int>(),t[2].cast<int>());
+        });
+
+
+
 };
